@@ -10,9 +10,9 @@ FE.UPWARD <- 0x800
 FE.TOWARDZERO <- 0xc00
 
 fegetround <- function() {
-  .C(r_fegetround, rounding.mode = integer(1))$rounding.mode
+  .C(C_r_fegetround, rounding.mode = integer(1))$rounding.mode
 }
 
 fesetround <- function(rounding.mode=FE.TONEAREST) {
-  .C(r_fesetround, rounding.mode = as.integer(rounding.mode))$rounding.mode
+  .C(C_r_fesetround, rounding.mode = as.integer(rounding.mode))$rounding.mode
 }
